const cacheName = 'images'

let accessToken

self.addEventListener('install', (event) => {
  self.skipWaiting()

  event.waitUntil(caches.open(cacheName))
})

self.addEventListener('message', (event) => {
  accessToken = event.data
})

self.addEventListener('fetch', (event) => {
  const { request } = event
  const { pathname, origin } = new URL(request.url)
  const cacheKey = `${origin}${pathname}`
  const headers = accessToken ? { Authorization: `Bearer ${accessToken}` } : {}
  // Check if this is a request for an image

  if (request.destination === 'image') {
    event.respondWith(caches.open(cacheName).then((cache) => {
      // Go to the cache first
      return cache.match(cacheKey).then((cachedResponse) => {
        // Return a cached response if we have one
        if (cachedResponse) {
          return cachedResponse
        }

        // Otherwise, hit the network
        return fetch(request, {
          mode: 'cors',
          headers
        }).then((fetchedResponse) => {
          // Add the network response to the cache for later visits
          if (fetchedResponse.ok) cache.put(cacheKey, fetchedResponse.clone())

          // Return the network response
          return fetchedResponse
        })
      })
    }))
  } else {
    // do nothing
  }
})
